@@ -179,11 +179,11 @@ setMethod("export", c("GenomicRanges", "BEDFile"),
             options(scipen = 100) # prevent use of scientific notation
             on.exit(options(scipen = scipen))
             file <- con
-            con <- connection(con, if (append) "a" else "w")
-            on.exit(release(con), add=TRUE)
+            m <- manager()
+            con <- connection(m, con, if (append) "a" else "w")
             write.table(df, con, sep = "\t", col.names = FALSE,
                         row.names = FALSE, quote = FALSE, na = ".")
-            release(con)
+            release(m, con)
             if (index)
               invisible(indexTrack(file))
             else invisible(file)
@@ -225,7 +225,9 @@ setMethod("import.bed", "ANY",
           })
 
 scanTrackLine <- function(con) {
-  con <- connectionForResource(con, "r")
+  m <- manager()
+  con <- connectionForResource(m, con, "r")
+  on.exit(release(m, con))
   line <- "#"
   while(length(grep("^ *#", line))) # skip initial comments
     line <- readLines(con, 1, warn = FALSE)
@@ -240,12 +242,16 @@ scanTrackLine <- function(con) {
 setMethod("import", "BEDFile",
           function(con, format, text, trackLine = TRUE,
                    genome = NA, colnames = NULL,
-                   which = NULL, seqinfo = NULL, extraCols = character())
+                   which = NULL, seqinfo = NULL, extraCols = character(),
+                   sep = c("\t", ""))
           {
             if (!missing(format))
               checkArgFormat(con, format)
+            sep <- match.arg(sep)
             file <- con
-            con <- queryForConnection(con, which)
+            m <- manager()
+            con <- queryForConnection(m, con, which)
+            on.exit(release(m, con))
             if (attr(con, "usedWhich"))
                 which <- NULL
             if (is(genome, "Seqinfo")) {
@@ -300,7 +306,8 @@ setMethod("import", "BEDFile",
               `tail<-` <- function(x, n, value)
                 if (n != 0) c(head(x, -n), value) else x
               pushBack(line, con)
-              colsInFile <- seq_len(length(strsplit(line, "\\s+")[[1]]))
+              pattern <- if (sep == "") "\\s+" else "\\t"
+              colsInFile <- seq_len(length(strsplit(line, pattern)[[1L]]))
               presentNames <- bedNames[colsInFile]
               lacksNames <- is.null(names(extraCols)) ||
                   any(names(extraCols) == "") ||
@@ -323,8 +330,8 @@ setMethod("import", "BEDFile",
               bed <- DataFrame(read.table(con, colClasses = bedClasses,
                                           as.is = TRUE, na.strings = ".",
                                           comment.char = "",
-                                          sep = "\t",
-                                          quote = "\""))
+                                          sep = sep,
+                                          quote = ""))
             } else {
               if (is.null(colnames))
                 colnames <- character()
@@ -641,11 +648,11 @@ setMethod("export", c("Pairs", "BEDPEFile"),
             options(scipen = 100) # prevent use of scientific notation
             on.exit(options(scipen = scipen))
             file <- con
-            con <- connection(con, if (append) "a" else "w")
-            on.exit(release(con), add=TRUE)
+            m <- manager()
+            con <- connection(m, con, if (append) "a" else "w")
+            on.exit(release(m, con), add=TRUE)
             write.table(df, con, sep = "\t", col.names = FALSE,
                         row.names = FALSE, quote = FALSE, na = ".")
-            release(con)
             invisible(file)
           })
 
