@@ -262,7 +262,10 @@ setMethod("import", "GFFFile",
                 }
             }
 
-            sniffed <- .sniffGFFVersion(resource(con))
+            m <- manager()
+            sniff_con <- connection(m, con, "r")
+            on.exit(release(m, sniff_con))
+            sniffed <- .sniffGFFVersion(sniff_con)
             version <- gffFileVersion(con)
             if (!length(version)) {
               if (is.null(sniffed))
@@ -289,10 +292,10 @@ setMethod("import", "GFFFile",
 
             ## Temporarily disable use of Tabix Index.
             ## TODO: Restore use of Tabix Index!
-            #con <- queryForResource(con, which)
-            con <- queryForResource(con)
-
-            ans <- readGFFAsGRanges(con,
+            #con <- queryForResource(m, con, which)
+            resource <- queryForResource(m, con)
+            on.exit(release(m, resource), add=TRUE)
+            ans <- readGFFAsGRanges(resource,
                                     version=version,
                                     colnames=colnames,
                                     filter=list(type=feature.type),
@@ -300,7 +303,7 @@ setMethod("import", "GFFFile",
                                     sequenceRegionsAsSeqinfo=
                                         sequenceRegionsAsSeqinfo,
                                     speciesAsMetadata=TRUE)
-            if (!attr(con, "usedWhich") && !is.null(which))
+            if (!attr(resource, "usedWhich") && !is.null(which))
                 ans <- subsetByOverlaps(ans, which)
             ans
           })
@@ -442,7 +445,9 @@ setMethod("asGTF", "GRangesList",
 ###
 
 scanGFFDirectives <- function(con, tag = NULL) {
-  con <- connection(con, "r")
+  m <- manager()
+  con <- connection(m, con, "r")
+  on.exit(release(m, con))
   directives <- character()
   lines <- line <- readLines(con, n = 1)
   while(grepl("^#", line)) {
@@ -476,7 +481,6 @@ gffComment <- function(con, ...)
   cat("##", paste(...), "\n", sep = "", file = con, append = TRUE)
 
 .sniffGFFVersion <- function(con) {
-  con <- connectionForResource(con, "r")
   version <- NULL
   lines <- line <- readLines(con, n = 1)
   while(grepl("^#", line)) {
