@@ -66,6 +66,12 @@ normArgTrackData <- function(value, session) {
   value
 }
 
+handleError <- function(response) {
+    msg <- getNodeSet(response, "//span[text()='Error']/../text()")
+    if (length(msg) == 2L)
+        stop(sub(".*? - ", "", xmlValue(msg[[2L]])))
+}
+
 setReplaceMethod("track", c("UCSCSession", "GenomicRangesList"),
           function(object, name = names(value),
                    format = c("auto", "bed", "wig", "gff1", "bed15",
@@ -83,7 +89,7 @@ setReplaceMethod("track", c("UCSCSession", "GenomicRangesList"),
                      {
                        form <- ucscForm(tracks, format, ...)
                        response <- ucscPost(object, "custom", form)
-### FIXME: need to check for error
+                       handleError(response)
                      })
             }
             object
@@ -301,6 +307,14 @@ setMethod("ucscTableQuery", "UCSCSession",
             query
           })
 
+setMethod("ucscTableQuery", "character",
+          function(x, ...) {
+              stopifnot(isSingleString(x))
+              session <- browserSession()
+              genome(session) <- x
+              ucscTableQuery(session, ...)
+          })
+
 ucscTableGet <- function(query, .parse = TRUE, tracks = FALSE, ...)
   ucscGet(browserSession(query), "tables",
           c(ucscForm(query, tracks = tracks), ...), .parse = .parse)
@@ -644,9 +658,10 @@ setMethod("getTable", "UCSCTableQuery",
               output <- gsub("\\n.*", "", output)
             f <- file()
             writeLines(output, f)
-            header <- readChar(f, 1) ## strip off the '#' header prefix
             tab <- read.table(f, sep = "\t", header=TRUE, comment.char = "",
                               quote = "")
+            ## strip off the '#' => 'X.' header prefix
+            colnames(tab)[1L] <- substring(colnames(tab)[1L], 3L)
             close(f)
             tab
           })
@@ -922,8 +937,7 @@ setAs("TrackLine", "character",
           str <- paste(str, " visibility=", vis, sep="")
         color <- from@color
         if (length(color))
-            str <- paste0(str, " color=",
-                          paste0("\"", color, "\"", collapse=","))
+            str <- paste0(str, " color=\"", paste0(color, collapse=","), "\"")
         priority <- from@priority
         if (length(priority))
           str <- paste(str, " priority=", priority, sep="")
@@ -1237,11 +1251,13 @@ setMethod("export", c("GenomicRangesList", "UCSCFile"),
             ucsc <- unlist(lapply(object, is, "UCSCData"))
             lines <- unlist(lapply(object[ucsc], slot, "trackLine"))
             trackNames[ucsc] <- as.character(sapply(lines, slot, "name"))
+            tracks <- vector("list", length(object))
             for (i in seq_len(length(object))) {
-              export(object[[i]], con, name = trackNames[i],
-                     append = append, index = index, ...)
+              tracks[[i]] <- export(object[[i]], con, name = trackNames[i],
+                                    append = append, index = index, ...)
               append <- TRUE
             }
+            RTLFileList(tracks)
           })
 
 trackLineClass <- function(subformat)
@@ -1344,13 +1360,12 @@ setMethod("export", c("UCSCData", "UCSCFile"),
               trackLine <- object@trackLine
             }
             file <- con
-            con <- connection(con, if (append) "a" else "w")
-            on.exit(release(con))
+            m <- manager()
+            con <- connection(m, con, if (append) "a" else "w")
             cat(as(object@trackLine, "character"), "\n", file=con, sep = "")
-            do.call(export, c(list(as(object, "GRanges"), unmanage(con),
-                                   subformat),
+            do.call(export, c(list(as(object, "GRanges"), con, subformat),
                               args[!lineArgs], trackLine = trackLine))
-            release(con)
+            release(m, con)
             if (index)
               indexTrack(FileForFormat(resource(file), subformat), skip = 1L)
             else invisible(file)
